mappingObject = {
    "amazon_campaigns": "graas_amazon_campaigns",
    "flipkart_campaigns": "graas_flipkart_campaigns",
    "affiliate_report_daily": "graas_mkp_affiliate_report_daily",
    "deals_overview_daily": "graas_mkp_deals_overview_daily",
    "deals_trends_daily": "graas_mkp_deals_trends_daily",
    "offsite_campaigns": "graas_mkp_offsite_campaigns",
    "onsite_campaigns": "graas_mkp_onsite_campaigns",
    "onsite_keywords": "graas_mkp_onsite_keywords",
    "product_campaign_performance": "graas_mkp_product_campaign_performance",
    "product_overview_daily": "graas_mkp_product_overview_daily",
    "product_overview_hourly": "graas_mkp_product_overview_hourly",
    "product_performance": "graas_mkp_product_performance",
    "shop_stats_daily": "graas_mkp_shop_stats_daily",
    "shop_stats_hourly": "graas_mkp_shop_stats_hourly",
    "traffic_overview_daily": "graas_mkp_traffic_overview_daily",
    "traffic_overview_hourly": "graas_mkp_traffic_overview_hourly",
    "voucher_performance_daily": "graas_mkp_voucher_performance_daily",
}



import json
import os
import jsonschema
from .ref_Resolver import ExtendedRefResolver
from .configs import mappingObject
# from pkg_resources import resource_filename
import importlib_resources

def executeValidateJson(data, schema):
    try:
        jsonschema.validate(
            data,
            schema,
            resolver=ExtendedRefResolver(
                # base_uri=resource_filename(__name__, '/Schema'),
                base_uri=importlib_resources.files(__name__) / 'Schema',
                referrer=schema,
            ),
        )
    except jsonschema.exceptions.ValidationError as err:
        return {"status": "SCHEMA_VALIDATION_FAILED", "message": err.message}
    return {
        "status": "SCHEMA_VALIDATION_SUCCESS",
        "message": "Schema successfully validated",
    }


def extract_data_from_file(schema_file):
    # path_for_schema = resource_filename(__name__, '/Schema')
    path_for_schema = importlib_resources.files(__name__) / 'Schema'

    with open(f"{path_for_schema}/{schema_file}.json", "r") as schema_file:
        schemaObj = json.load(schema_file)

    return schemaObj


def validateJson(dataJsonString, reportType):
    if reportType is None or not reportType:
        return {
            "status": "SCHEMA_VALIDATION_FAILED",
            "message": "Report type is Empty or None please enter valid string value!",
        }

    schema_file = mappingObject.get(reportType, "")

    if schema_file:
        try:
            jsonObject = json.loads(dataJsonString)
        except Exception as err:
            print("Error in converting data from string to json", err)
            return {
                "status": "SCHEMA_VALIDATION_FAILED",
                "message": "Error in converting data from string to json",
            }
        if jsonObject:
            schemaObject = extract_data_from_file(schema_file)
            isValidated = executeValidateJson(jsonObject, schemaObject)
            return isValidated
        else:
            return {
                "status": "SCHEMA_VALIDATION_FAILED",
                "message": "Object is empty please enter correct object",
            }
    else:
        return {
            "status": "SCHEMA_VALIDATION_FAILED",
            "message": "Report type which you have entered is not correct or empty please update and try again!",
        }



from setuptools import setup, find_packages 

# reading long description from file 
# with open('DESCRIPTION.txt') as file: 
# 	long_description = file.read()


# specify requirements of your package here 
REQUIREMENTS = ['jsonschema']

# some more details 
CLASSIFIERS = [ 
	'Development Status :: 4 - Beta', 
	'Intended Audience :: Developers', 
	'Topic :: Internet', 
	'License :: OSI Approved :: MIT License', 
	'Programming Language :: Python', 
	'Programming Language :: Python :: 2', 
	'Programming Language :: Python :: 2.6', 
	'Programming Language :: Python :: 2.7', 
	'Programming Language :: Python :: 3', 
	'Programming Language :: Python :: 3.3', 
	'Programming Language :: Python :: 3.4', 
	'Programming Language :: Python :: 3.8', 
	]

# calling the setup function 
setup(name='graas-observability-utility', 
	version='1.0.36', 
	description='A small wrapper around data observability', 
	# long_description=long_description, 
	url='https://bitbucket.org/shoptimizeanalytics/graas-observability-utility', 
	author='Graas', 
	author_email='priyanka.patel@graas.ai', 
	# license='MIT',
    packages=find_packages(),
    # data_files=[('graas_utilities', ['schemas/*.json'])],
    include_package_data=True,    
	classifiers=CLASSIFIERS, 
	install_requires=REQUIREMENTS, 
	keywords='utility'
	)
